<?php

switch ($messaggio) {

case "via":  				$messaggio = "gata"; break;
case "Torna indietro":  		$messaggio = "Tillbaka"; break;
case "Da":  				$messaggio = "Fr&aring;n"; break;
case "A":  				$messaggio = "Till"; break;
case "Oggetto":  			$messaggio = "&Auml;mne"; break;
case "Allega":  			$messaggio = "Bilaga"; break;
case "Spedisci":  			$messaggio = "S&auml;nd"; break;
case "L'email a":  			$messaggio = "E-posten till"; break;
case "è stata inviata":  		$messaggio = "har s&auml;nts"; break;
case "bcc a":  				$messaggio = "hemlig kopia till"; break;
case "Non si è potuto inviare l'email a":	$messaggio = "Det gick inte att skicka e-posten till"; break;
case "documento":  			$messaggio = "dokument"; break;
case "Cancella il documento":  		$messaggio = "Ta bort detta dokument"; break;
case "Cancella i documenti":  		$messaggio = "Ta bort dom h&auml;r dokumenten"; break;
case "Il documento":  			$messaggio = "Dokumentet"; break;
case "è stato <b style=\"font-weight: normal; color: blue;\">cancellato</b>":	$messaggio = "har <b style=\"font-weight: normal; color: blue;\">tagits bort</b>"; break;
case "Transazione <font color=\"red\">scaduta</font>":	$messaggio = "<font color=\"red\">Utg&aring;ngen</font> &ouml;verf&ouml;ring"; break;
case "Sovrascrivi":  			$messaggio = "Skriv &ouml;ver"; break;
case "Documenti già esistenti riguardanti questa prenotazione":	$messaggio = "Redan existerande dokument f&ouml;r den h&auml;r bokningen"; break;
case "Documenti già esistenti riguardanti queste prenotazioni":	$messaggio = "Redan existerande dokument f&ouml;r dom h&auml;r bokningarna"; break;
case "Salva dei nuovi documenti":  	$messaggio = "Spara nya dokument"; break;
case "Salva un nuovo documento":  	$messaggio = "Spara ett nytt dokument"; break;
case "in data":  			$messaggio = "on"; break;
case "<span class=\"colblu\">salvato</span> come":	$messaggio = "<span class=\"colblu\">saved</span> as"; break;
case "<span class=\"colblu\">Attenzione</span>: una email con lo stesso oggetto è già stata inviata al cliente":	$messaggio = "<span class=\"colblu\">Warning</span>: an email with the same subject has already been sent to client"; break;
case "Errore":  			$messaggio = "Error"; break;
case "ha scritto":  			$messaggio = "wrote"; break;
case "Non si è potuto mascherare il mittente dell'email perchè attualmente <b class=\"colwarn\">SPF non è configurato correttamente</b> sul dominio della email":	$messaggio = "It was not possible to masquerade the sender of the email because currently <b class=\"colwarn\">SPF is not configured correctly</b> on the domain of email"; break;
case "L'utente amministratore può cambiare questa inpostazione in":	$messaggio = "The administrator user can change this setting in"; break;
case "configura e personalizza":  	$messaggio = "configure and customize"; break;
case "È stato raggiunto il numero massimo di email giornaliere":	$messaggio = "You have reached the maximum number of daily emails"; break;
case "Per mandare altre email l'utente amministratore può impostare un server remoto in":	$messaggio = "To comtinue sending emails the administrator user can set a remote server in"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)



?>